@@ -11,8 +11,6 @@ use Mojo::Util qw(class_to_path slurp);
 
 has parts => sub { [] };
 
-sub new { shift->SUPER::new->parse(@_) }
-
 sub detect {
   my $self = shift;
 
@@ -62,6 +60,8 @@ sub list_files {
 
 sub mojo_lib_dir { catdir(dirname(__FILE__), '..') }
 
+sub new { shift->SUPER::new->parse(@_) }
+
 sub parse {
   my ($self, $path) = @_;
   return defined $path ? $self->parts([splitdir $path]) : $self;
@@ -111,14 +111,6 @@ Home directory parts.
 L<Mojo::Home> inherits all methods from L<Mojo::Base> and implements the
 following new ones.
 
-=head2 new
-
-  my $home = Mojo::Home->new;
-  my $home = Mojo::Home->new('/home/sri/myapp');
-
-Construct a new L<Mojo::Home> object and L</"parse"> home directory if
-necessary.
-
 =head2 detect
 
   $home = $home->detect;
@@ -149,6 +141,14 @@ directory.
 
 Path to C<lib> directory in which L<Mojolicious> is installed.
 
+=head2 new
+
+  my $home = Mojo::Home->new;
+  my $home = Mojo::Home->new('/home/sri/myapp');
+
+Construct a new L<Mojo::Home> object and L</"parse"> home directory if
+necessary.
+
 =head2 parse
 
   $home = $home->parse('/home/sri/myapp');
@@ -171,10 +171,25 @@ Portably generate an absolute path for a file relative to the home directory.
 =head2 to_string
 
   my $str = $home->to_string;
-  my $str = "$home";
 
 Home directory.
 
+=head1 OPERATORS
+
+L<Mojo::Home> overloads the following operators.
+
+=head2 bool
+
+  my $bool = !!$home;
+
+Always true.
+
+=head2 stringify
+
+  my $str = "$home";
+
+Alias for L</to_string>.
+
 =head1 SEE ALSO
 
 L<Mojolicious>, L<Mojolicious::Guides>, L<http://mojolicio.us>.
