@@ -43,7 +43,7 @@ has types     => sub { Mojolicious::Types->new };
 has validator => sub { Mojolicious::Validator->new };
 
 our $CODENAME = 'Top Hat';
-our $VERSION  = '4.71';
+our $VERSION  = '4.72';
 
 sub AUTOLOAD {
   my $self = shift;
@@ -312,6 +312,20 @@ differently. (Passed a callback leading to the next hook, the current
 controller object, the action callback and a flag indicating if this action is
 an endpoint)
 
+=head2 before_render
+
+Emitted before content is generated by the renderer. Note that this hook can
+trigger out of order due to its dynamic nature, and with embedded applications
+will only work for the application that is rendering.
+
+  $app->hook(before_render => sub {
+    my ($c, $args) = @_;
+    ...
+  });
+
+Mostly used for pre-processing arguments passed to the renderer. (Passed the
+current controller object and the render arguments)
+
 =head2 after_render
 
 Emitted after content has been generated by the renderer that is not partial.
@@ -587,11 +601,11 @@ requests indiscriminately, for a full list of available hooks see L</"HOOKS">.
 
   my $app = Mojolicious->new;
 
-Construct a new L<Mojolicious> application, calling C<${mode}_mode> and
-L</"startup"> in the process. Will automatically detect your home directory
-and set up logging based on your current operating mode. Also sets up the
-renderer, static file server, a default set of plugins and an
-L</"around_dispatch"> hook with the default exception handling.
+Construct a new L<Mojolicious> application and call L</"startup">. Will
+automatically detect your home directory and set up logging based on your
+current operating mode. Also sets up the renderer, static file server, a
+default set of plugins and an L</"around_dispatch"> hook with the default
+exception handling.
 
 =head2 plugin
 
